@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '1.016000';
+$MetaCPAN::Client::Request::VERSION = '1.017000';
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
@@ -51,6 +51,12 @@ has ua_args => (
     },
 );
 
+has _is_agg => (
+    is      => 'ro',
+    default => 0,
+    writer  => '_set_is_agg'
+);
+
 sub _build_ua {
     my $self = shift;
     # This level of indirection is so that if a user has not specified a custom UA
@@ -84,7 +90,7 @@ sub ssearch {
     my $params = shift;
 
     my $es = Search::Elasticsearch->new(
-        nodes            => $self->domain,
+        nodes            => [ 'https://' . $self->domain ],
         cxn_pool         => 'Static::NoPing',
         send_get_body_as => 'POST',
         ( $self->_has_user_ua ? ( handle => $self->_user_ua ) : () )
@@ -93,7 +99,7 @@ sub ssearch {
     my $body = $self->_build_body($args, $params);
 
     my $scroller = $es->scroll_helper(
-        search_type => 'scan',
+        ( search_type => 'scan' ) x !$self->_is_agg,
         scroll      => '5m',
         index       => $self->version,
         type        => $type,
@@ -146,7 +152,8 @@ sub _build_body {
     return +{
         query => $query,
         _read_filters($params),
-        _read_facets($params)
+        $self->_read_facets($params),
+        $self->_read_aggregations($params)
     };
 }
 
@@ -157,14 +164,27 @@ my %key2es = (
 );
 
 sub _read_facets {
+    my $self   = shift;
     my $params = shift;
 
     my $facets = delete $params->{facets};
     ref($facets) or return ();
 
+    $self->_set_is_agg(1);
     return ( facets => $facets );
 }
 
+sub _read_aggregations {
+    my $self   = shift;
+    my $params = shift;
+
+    my $aggregations = delete $params->{aggregations};
+    ref($aggregations) or return ();
+
+    $self->_set_is_agg(1);
+    return ( aggregations => $aggregations );
+}
+
 sub _read_filters {
     my $params = shift;
 
@@ -232,7 +252,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 1.016000
+version 1.017000
 
 =head1 ATTRIBUTES
 
