@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::ResultSet;
 # ABSTRACT: A Result Set
-$MetaCPAN::Client::ResultSet::VERSION = '1.016000';
+$MetaCPAN::Client::ResultSet::VERSION = '1.017000';
 use Moo;
 use Carp;
 
@@ -75,6 +75,12 @@ sub facets {
     return $self->has_scroller ? $self->scroller->facets : {};
 }
 
+sub aggregations {
+    my $self = shift;
+
+    return $self->has_scroller ? $self->scroller->aggregations : {};
+}
+
 1;
 
 __END__
@@ -89,7 +95,7 @@ MetaCPAN::Client::ResultSet - A Result Set
 
 =head1 VERSION
 
-version 1.016000
+version 1.017000
 
 =head1 DESCRIPTION
 
@@ -127,6 +133,10 @@ The entity of the result set. Available types:
 
 =back
 
+=head2 aggregations
+
+The aggregations available in the Elastic Search response.
+
 =head2 facets
 
 The facets available in the Elastic Search response.
